pyMez.Code.FrontEnds.HTMLPanel API documentation
Description: Help --------------- <a href=

`pyMez.Code.FrontEnds`

Top

# pyMez.Code.FrontEnds.HTMLPanel module

## Help

`pyMez.Code.FrontEnds`

Documentation Home | API Documentation Home | Examples Home | Index

Show source ≡

    #-----------------------------------------------------------------------------
    # Name:        HTMLTestPanel.py
    # Purpose:     To test using an XSL tranform and a custom HYPERLINK handler
    # Author:      Aric Sanders
    # Created:     3/02/2016
    # License:     MIT License
    #-----------------------------------------------------------------------------
    #Boa:FramePanel:Panel1
    """
    Help
    ---------------
    <a href="./index.html">`pyMez.Code.FrontEnds`</a>
    <div>
    <a href="../../../pyMez_Documentation.html">Documentation Home</a> |
    <a href="../../index.html">API Documentation Home</a> |
    <a href="../../../Examples/html/Examples_Home.html">Examples Home</a> |
    <a href="../../../Reference_Index.html">Index</a>
    </div>
    """
    import wx
    import wx.html
    import re
    TEST_HTML="<h1>This is a Test String<h1>"

    class LinkError(Exception):
        pass
    class HTMLWindow(wx.html.HtmlWindow):
        """ speciallized Html window """
        # Overloading the method is deprecated, just intercept the event
        def OnLinkClicked(self,link_info):
            """This is the href handler"""

            try:
                function_id=link_info.split(',')[0]

                if re.search('edit',function_id):
                    passdlg = wx.TextEntryDialog(self, 'Edit Value', 'Value',
                    'test')
                    try:
                        if passdlg.ShowModal() == wx.ID_OK:
                            result = passdlg.GetValue()
                                # Your code
                    finally:
                        passdlg.Destroy()
                else:
                    raise LinkError
            except LinkError:
                # This behavior is deprecated ...
                self.base_OnLinkedClicked(link_info)
    [wxID_PANEL1, wxID_PANEL1HTMLWINDOW1,
    ] = [wx.NewId() for _init_ctrls in range(2)]

    class Panel1(wx.Panel):
        _custom_classes = {'wx.html.HtmlWindow': ['HTMLWindow']}
        def _init_coll_boxSizer1_Items(self, parent):
            # generated method, don't edit

            parent.Add(self.htmlWindow1, 1, border=0, flag=wx.EXPAND)

        def _init_sizers(self):
            # generated method, don't edit
            self.boxSizer1 = wx.BoxSizer(orient=wx.VERTICAL)

            self._init_coll_boxSizer1_Items(self.boxSizer1)

            self.SetSizer(self.boxSizer1)

        def _init_ctrls(self, prnt):
            # generated method, don't edit
            wx.Panel.__init__(self, id=wxID_PANEL1, name='', parent=prnt,
                  pos=wx.Point(299, 165), size=wx.Size(1110, 547),
                  style=wx.TAB_TRAVERSAL)
            self.SetClientSize(wx.Size(1102, 513))
            self.SetForegroundColour(wx.Colour(128, 0, 64))

            self.htmlWindow1 = HTMLWindow(id=wxID_PANEL1HTMLWINDOW1,
                  name='htmlWindow1', parent=self, pos=wx.Point(0, 0),
                  size=wx.Size(1102, 513), style=wx.html.HW_SCROLLBAR_AUTO)

            self._init_sizers()

        def __init__(self, parent, id, pos, size, style, name):
            self._init_ctrls(parent)

    if __name__ == '__main__':
        app = wx.App(False)
        frame = wx.Frame(None,size=wx.Size(762, 502))
        panel=Panel1(id=1, name='HTMLPanel',
                  parent=frame, pos=wx.Point(350, 204), size=wx.Size(762, 502),
                  style=wx.TAB_TRAVERSAL)
        panel.htmlWindow1.LoadPage("http://www.example.com")
        sizer=wx.BoxSizer()
        sizer.Add(panel,1,wx.EXPAND,2)
        frame.SetSizerAndFit(sizer)
        frame.SetSize(wx.Size(800, 600))

        frame.Show()
        app.MainLoop()

## Classes

class HTMLWindow

speciallized Html window

Show source ≡

    class HTMLWindow(wx.html.HtmlWindow):
        """ speciallized Html window """
        # Overloading the method is deprecated, just intercept the event
        def OnLinkClicked(self,link_info):
            """This is the href handler"""

            try:
                function_id=link_info.split(',')[0]

                if re.search('edit',function_id):
                    passdlg = wx.TextEntryDialog(self, 'Edit Value', 'Value',
                    'test')
                    try:
                        if passdlg.ShowModal() == wx.ID_OK:
                            result = passdlg.GetValue()
                                # Your code
                    finally:
                        passdlg.Destroy()
                else:
                    raise LinkError
            except LinkError:
                # This behavior is deprecated ...
                self.base_OnLinkedClicked(link_info)

### Ancestors (in MRO)

- HTMLWindow
- wx._html.HtmlWindow
- wx._core.ScrolledWindow
- wx._core._ScrolledWindowBase
- wx._core.Window
- wx._core.WindowBase
- wx._core.EvtHandler
- wx._core.Object
- wx._core.Trackable
- wx._html.HtmlWindowInterface
- sip.wrapper
- sip.simplewrapper
- builtins.object

### Class variables

var ChildrenRepositioningGuard

var HTMLCursor

var HTMLCursor_Default

var HTMLCursor_Link

var HTMLCursor_Text

### Static methods

def Bind(

self, event, handler, source=None, id=-1, id2=-1)

Bind an event to an event handler.

:param event: One of the `EVT_*` event binder objects that specifies the type of event to bind.

:param handler: A callable object to be invoked when the event is delivered to self. Pass `None` to disconnect an event handler.

:param source: Sometimes the event originates from a different window than self, but you still want to catch it in self. (For example, a button event delivered to a frame.) By passing the source of the event, the event handling system is able to differentiate between the same event type from different controls.

:param id: Used to spcify the event source by ID instead of instance.

:param id2: Used when it is desirable to bind a handler to a range of IDs, such as with EVT_MENU_RANGE.

Show source ≡

    def _EvtHandler_Bind(self, event, handler, source=None, id=wx.ID_ANY, id2=wx.ID_ANY):
        """
        Bind an event to an event handler.

        :param event: One of the ``EVT_*`` event binder objects that
                      specifies the type of event to bind.

        :param handler: A callable object to be invoked when the
                        event is delivered to self.  Pass ``None`` to
                        disconnect an event handler.

        :param source: Sometimes the event originates from a
                       different window than self, but you still
                       want to catch it in self.  (For example, a
                       button event delivered to a frame.)  By
                       passing the source of the event, the event
                       handling system is able to differentiate
                       between the same event type from different
                       controls.

        :param id: Used to spcify the event source by ID instead
                   of instance.

        :param id2: Used when it is desirable to bind a handler
                    to a range of IDs, such as with EVT_MENU_RANGE.
        """
        assert isinstance(event, wx.PyEventBinder)
        assert callable(handler) or handler is None
        assert source is None or hasattr(source, 'GetId')
        if source is not None:
            id  = source.GetId()
        event.Bind(self, id, id2, handler)

def ConvertDialogPointToPixels(

*args, **kw)

Show source ≡

    def deprecated_func(*args, **kw):
        warnings.warn("Call to deprecated item%s. %s" % (name, msg),
                      wxPyDeprecationWarning, stacklevel=2)
        if not kw:
            return item(*args)
        return item(*args, **kw)

def ConvertDialogSizeToPixels(

*args, **kw)

Show source ≡

    def deprecated_func(*args, **kw):
        warnings.warn("Call to deprecated item%s. %s" % (name, msg),
                      wxPyDeprecationWarning, stacklevel=2)
        if not kw:
            return item(*args)
        return item(*args, **kw)

def DLG_UNIT(

self, dlg_unit)

A convenience wrapper for :meth:`ConvertDialogToPixels`.

Show source ≡

    def _Window_DLG_UNIT(self, dlg_unit):
        """
        A convenience wrapper for :meth:`ConvertDialogToPixels`.
        """
        is_wxType = isinstance(dlg_unit, (wx.Size, wx.Point))
        pix = self.ConvertDialogToPixels(dlg_unit)
        if not is_wxType:
            pix = tuple(pix)
        return pix

def DestroyLater(

self)

Schedules the window to be destroyed in the near future.

This should be used whenever Destroy could happen too soon, such as when there may still be events for this window or its children waiting in the event queue.

Show source ≡

    def _Window_DestroyLater(self):
        """
        Schedules the window to be destroyed in the near future.

        This should be used whenever Destroy could happen too soon, such
        as when there may still be events for this window or its children
        waiting in the event queue.
        """
        self.Hide()
        wx.GetApp().ScheduleForDestruction(self)

def GetPositionTuple(

*args, **kw)

Show source ≡

    def deprecated_func(*args, **kw):
        warnings.warn("Call to deprecated item%s. %s" % (name, msg),
                      wxPyDeprecationWarning, stacklevel=2)
        if not kw:
            return item(*args)
        return item(*args, **kw)

def GetSizeTuple(

*args, **kw)

Show source ≡

    def deprecated_func(*args, **kw):
        warnings.warn("Call to deprecated item%s. %s" % (name, msg),
                      wxPyDeprecationWarning, stacklevel=2)
        if not kw:
            return item(*args)
        return item(*args, **kw)

def GetVirtualSizeTuple(

*args, **kw)

Show source ≡

    def deprecated_func(*args, **kw):
        warnings.warn("Call to deprecated item%s. %s" % (name, msg),
                      wxPyDeprecationWarning, stacklevel=2)
        if not kw:
            return item(*args)
        return item(*args, **kw)

def MoveXY(

*args, **kw)

Show source ≡

    def deprecated_func(*args, **kw):
        warnings.warn("Call to deprecated item%s. %s" % (name, msg),
                      wxPyDeprecationWarning, stacklevel=2)
        if not kw:
            return item(*args)
        return item(*args, **kw)

def OnLinkClicked(

self, link_info)

This is the href handler

Show source ≡

    def OnLinkClicked(self,link_info):
        """This is the href handler"""

        try:
            function_id=link_info.split(',')[0]

            if re.search('edit',function_id):
                passdlg = wx.TextEntryDialog(self, 'Edit Value', 'Value',
                'test')
                try:
                    if passdlg.ShowModal() == wx.ID_OK:
                        result = passdlg.GetValue()
                            # Your code
                finally:
                    passdlg.Destroy()
            else:
                raise LinkError
        except LinkError:
            # This behavior is deprecated ...
            self.base_OnLinkedClicked(link_info)

def PostCreate(

*args, **kw)

Show source ≡

    def deprecated_func(*args, **kw):
        warnings.warn("Call to deprecated item%s. %s" % (name, msg),
                      wxPyDeprecationWarning, stacklevel=2)
        if not kw:
            return item(*args)
        return item(*args, **kw)

def SetClientRect(

self, rect)

Show source ≡

    def _Window_SetClientRect(self, rect):
        return self.SetClientSize(rect)

def SetDimensions(

*args, **kw)

SetDimensions(x, y, width, height, sizeFlags=SIZE_AUTO)

Show source ≡

    def deprecated_func(*args, **kw):
        warnings.warn("Call to deprecated item%s. %s" % (name, msg),
                      wxPyDeprecationWarning, stacklevel=2)
        if not kw:
            return item(*args)
        return item(*args, **kw)

def SetRect(

self, rect)

Show source ≡

    def _Window_SetRect(self, rect):
        return self.SetSize(rect)

def SetSizeHintsSz(

*args, **kw)

Show source ≡

    def deprecated_func(*args, **kw):
        warnings.warn("Call to deprecated item%s. %s" % (name, msg),
                      wxPyDeprecationWarning, stacklevel=2)
        if not kw:
            return item(*args)
        return item(*args, **kw)

def SetSizeWH(

*args, **kw)

Show source ≡

    def deprecated_func(*args, **kw):
        warnings.warn("Call to deprecated item%s. %s" % (name, msg),
                      wxPyDeprecationWarning, stacklevel=2)
        if not kw:
            return item(*args)
        return item(*args, **kw)

def SetToolTipString(

*args, **kw)

Show source ≡

    def deprecated_func(*args, **kw):
        warnings.warn("Call to deprecated item%s. %s" % (name, msg),
                      wxPyDeprecationWarning, stacklevel=2)
        if not kw:
            return item(*args)
        return item(*args, **kw)

def SetVirtualSizeWH(

*args, **kw)

Show source ≡

    def deprecated_func(*args, **kw):
        warnings.warn("Call to deprecated item%s. %s" % (name, msg),
                      wxPyDeprecationWarning, stacklevel=2)
        if not kw:
            return item(*args)
        return item(*args, **kw)

def Unbind(

self, event, source=None, id=-1, id2=-1, handler=None)

Disconnects the event handler binding for event from `self`. Returns `True` if successful.

Show source ≡

    def _EvtHandler_Unbind(self, event, source=None, id=wx.ID_ANY, id2=wx.ID_ANY, handler=None):
        """
        Disconnects the event handler binding for event from `self`.
        Returns ``True`` if successful.
        """
        if source is not None:
            id  = source.GetId()
        return event.Unbind(self, id, id2, handler)

### Instance variables

var AcceleratorTable

GetAcceleratorTable() -> AcceleratorTable

Gets the accelerator table for this window.

var AutoLayout

GetAutoLayout() -> bool

Returns the sizer of which this window is a member, if any, otherwise NULL.

var BackgroundColour

GetBackgroundColour() -> Colour

Returns the background colour of the window.

var BackgroundStyle

GetBackgroundStyle() -> BackgroundStyle

Returns the background style of the window.

var BestSize

GetBestSize() -> Size

This functions returns the best acceptable minimal size for the window.

var BestVirtualSize

GetBestVirtualSize() -> Size

Return the largest of ClientSize and BestSize (as determined by a sizer, interior children, or other means)

var Border

GetBorder(flags) -> Border GetBorder() -> Border

Get the window border style from the given flags: this is different from simply doing flags & wxBORDER_MASK because it uses GetDefaultBorder() to translate wxBORDER_DEFAULT to something reasonable.

var Caret

GetCaret() -> Caret

Returns the caret() associated with the window.

var CharHeight

GetCharHeight() -> int

Returns the character height for this window.

var CharWidth

GetCharWidth() -> int

Returns the average character width for this window.

var Children

GetChildren() -> WindowList

Returns a reference to the list of the window's children.

var ClassInfo

GetClassInfo() -> ClassInfo

This virtual function is redefined for every class that requires run- time type information, when using the wxDECLARE_CLASS macro (or similar).

var ClassName

GetClassName() -> Char

Returns the class name of the C++ class using wxRTTI.

var ClientAreaOrigin

GetClientAreaOrigin() -> Point

Get the origin of the client area of the window relative to the window top left corner (the client area may be shifted because of the borders, scrollbars, other decorations...)

var ClientRect

GetClientRect() -> Rect

Get the client rectangle in window (i.e. client) coordinates.

var ClientSize

GetClientSize() -> Size

Returns the size of the window 'client area' in pixels.

var Constraints

GetConstraints() -> LayoutConstraints

Returns a pointer to the window's layout constraints, or NULL if there are none.

var ContainingSizer

GetContainingSizer() -> Sizer

Returns the sizer of which this window is a member, if any, otherwise NULL.

var Cursor

GetCursor() -> Cursor

Return the cursor associated with this window.

var DefaultAttributes

GetDefaultAttributes() -> VisualAttributes

Currently this is the same as calling wxWindow::GetClassDefaultAttributes(wxWindow::GetWindowVariant()).

var DropTarget

GetDropTarget() -> DropTarget

Returns the associated drop target, which may be NULL.

var EffectiveMinSize

GetEffectiveMinSize() -> Size

Merges the window's best size into the min size and returns the result.

var Enabled

IsEnabled() -> bool

Returns true if the window is enabled, i.e. if it accepts user input, false otherwise.

var EventHandler

GetEventHandler() -> EvtHandler

Returns the event handler for this window.

var EvtHandlerEnabled

GetEvtHandlerEnabled() -> bool

Returns true if the event handler is enabled, false otherwise.

var ExtraStyle

GetExtraStyle() -> long

Returns the extra style bits for the window.

var Font

GetFont() -> Font

Returns the font for this window.

var ForegroundColour

GetForegroundColour() -> Colour

Returns the foreground colour of the window.

var GrandParent

GetGrandParent() -> Window

Returns the grandparent of a window, or NULL if there isn't one.

var HTMLBackgroundColour

GetHTMLBackgroundColour() -> wx.Colour

Returns background colour to use by default.

var HTMLWindow

GetHTMLWindow() -> wx.Window

Returns the window used for rendering (may be NULL).

var Handle

GetHandle() -> UIntPtr

Returns the platform-specific handle of the physical window.

var HelpText

GetHelpText() -> String

Gets the help text to be used as context-sensitive help for this window.

var Id

GetId() -> WindowID

Returns the identifier of the window.

var InternalRepresentation

GetInternalRepresentation() -> HtmlContainerCell

Returns pointer to the top-level container.

var Label

GetLabel() -> String

Generic way of getting a label from any window, for identification purposes.

var LayoutDirection

GetLayoutDirection() -> LayoutDirection

Returns the layout direction for this window, Note that wxLayout_Default is returned if layout direction is not supported.

var MaxClientSize

GetMaxClientSize() -> Size

Returns the maximum size of window's client area.

var MaxHeight

GetMaxHeight() -> int

Returns the vertical component of window maximal size.

var MaxSize

GetMaxSize() -> Size

Returns the maximum size of the window.

var MaxWidth

GetMaxWidth() -> int

Returns the horizontal component of window maximal size.

var MinClientSize

GetMinClientSize() -> Size

Returns the minimum size of window's client area, an indication to the sizer layout mechanism that this is the minimum required size of its client area.

var MinHeight

GetMinHeight() -> int

Returns the vertical component of window minimal size.

var MinSize

GetMinSize() -> Size

Returns the minimum size of the window, an indication to the sizer layout mechanism that this is the minimum required size.

var MinWidth

GetMinWidth() -> int

Returns the horizontal component of window minimal size.

var Name

GetName() -> String

Returns the window's name.

var NextHandler

GetNextHandler() -> EvtHandler

Returns the pointer to the next handler in the chain.

var OpenedAnchor

GetOpenedAnchor() -> String

Returns anchor within currently opened page (see wxHtmlWindow::GetOpenedPage).

var OpenedPage

GetOpenedPage() -> String

Returns full location of the opened page.

var OpenedPageTitle

GetOpenedPageTitle() -> String

Returns title of the opened page or wxEmptyString if the current page does not contain tag.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.Parent" class="name">var <span class="ident">Parent</span></p> <div class="desc"><p>GetParent() -> Window</p> <p>Returns the parent of the window, or NULL if there is no parent.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.Parser" class="name">var <span class="ident">Parser</span></p> <div class="desc"><p>GetParser() -> HtmlWinParser</p> <p>Returns a pointer to the current parser.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.Position" class="name">var <span class="ident">Position</span></p> <div class="desc"><p>GetPosition() -> Point</p> <p>This gets the position of the window in pixels, relative to the parent window for the child windows or relative to the display origin for the top level windows.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.PreviousHandler" class="name">var <span class="ident">PreviousHandler</span></p> <div class="desc"><p>GetPreviousHandler() -> EvtHandler</p> <p>Returns the pointer to the previous handler in the chain.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.Rect" class="name">var <span class="ident">Rect</span></p> <div class="desc"><p>GetRect() -> Rect</p> <p>Returns the position and size of the window as a wxRect object.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.RefData" class="name">var <span class="ident">RefData</span></p> <div class="desc"><p>GetRefData() -> ObjectRefData</p> <p>Returns the wxObject::m_refData pointer, i.e. the data referenced by this object.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.RelatedFrame" class="name">var <span class="ident">RelatedFrame</span></p> <div class="desc"><p>GetRelatedFrame() -> wx.Frame</p> <p>Returns the related frame.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.ScaleX" class="name">var <span class="ident">ScaleX</span></p> <div class="desc"><p>GetScaleX() -> double</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.ScaleY" class="name">var <span class="ident">ScaleY</span></p> <div class="desc"><p>GetScaleY() -> double</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.ScreenPosition" class="name">var <span class="ident">ScreenPosition</span></p> <div class="desc"><p>GetScreenPosition() -> Point</p> <p>Returns the window position in screen coordinates, whether the window is a child window or a top level one.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.ScreenRect" class="name">var <span class="ident">ScreenRect</span></p> <div class="desc"><p>GetScreenRect() -> Rect</p> <p>Returns the position and size of the window on the screen as a wxRect object.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.Shown" class="name">var <span class="ident">Shown</span></p> <div class="desc"><p>IsShown() -> bool</p> <p>Returns true if the window is shown, false if it has been hidden.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.Size" class="name">var <span class="ident">Size</span></p> <div class="desc"><p>GetSize() -> Size</p> <p>Returns the size of the entire window in pixels, including title bar, border, scrollbars, etc.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.Sizer" class="name">var <span class="ident">Sizer</span></p> <div class="desc"><p>GetSizer() -> Sizer</p> <p>Returns the sizer associated with the window by a previous call to SetSizer(), or NULL.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.TargetRect" class="name">var <span class="ident">TargetRect</span></p> <div class="desc"><p>GetTargetRect() -> Rect</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.TargetWindow" class="name">var <span class="ident">TargetWindow</span></p> <div class="desc"><p>GetTargetWindow() -> Window</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.ThemeEnabled" class="name">var <span class="ident">ThemeEnabled</span></p> <div class="desc"><p>GetThemeEnabled() -> bool</p> <p>Clears the window by filling it with the current background colour.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.ToolTip" class="name">var <span class="ident">ToolTip</span></p> <div class="desc"><p>GetToolTip() -> ToolTip</p> <p>Get the associated tooltip or NULL if none.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.TopLevel" class="name">var <span class="ident">TopLevel</span></p> <div class="desc"><p>IsTopLevel() -> bool</p> <p>Returns true if the given window is a top-level one.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.TopLevelParent" class="name">var <span class="ident">TopLevelParent</span></p> <div class="desc"><p>GetTopLevelParent() -> Window</p> <p>Returns the first ancestor of this window which is a top-level window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.UpdateClientRect" class="name">var <span class="ident">UpdateClientRect</span></p> <div class="desc"><p>GetUpdateClientRect() -> Rect</p> <p>Get the update rectangle bounding box in client coords.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.UpdateRegion" class="name">var <span class="ident">UpdateRegion</span></p> <div class="desc"><p>GetUpdateRegion() -> Region</p> <p>Returns the region specifying which parts of the window have been damaged.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.Validator" class="name">var <span class="ident">Validator</span></p> <div class="desc"><p>GetValidator() -> Validator</p> <p>Validator functions.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.VirtualSize" class="name">var <span class="ident">VirtualSize</span></p> <div class="desc"><p>GetVirtualSize() -> Size</p> <p>This gets the virtual size of the window in pixels.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.WindowStyle" class="name">var <span class="ident">WindowStyle</span></p> <div class="desc"><p>GetWindowStyle() -> long</p> <p>See GetWindowStyleFlag() for more info.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.WindowStyleFlag" class="name">var <span class="ident">WindowStyleFlag</span></p> <div class="desc"><p>GetWindowStyleFlag() -> long</p> <p>Gets the window style that was passed to the constructor or Create() method.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.HTMLWindow.WindowVariant" class="name">var <span class="ident">WindowVariant</span></p> <div class="desc"><p>GetWindowVariant() -> WindowVariant</p> <p>Returns the value previously passed to SetWindowVariant().</p></div> <div class="source_cont"> </div> </div> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.LinkError" class="name">class <span class="ident">LinkError</span></p> <div class="desc"><p>Common base class for all non-exit exceptions.</p></div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.LinkError', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.LinkError" class="source"> <div class="codehilite"><pre><span></span><span class="k">class</span> <span class="nc">LinkError</span><span class="p">(</span><span class="ne">Exception</span><span class="p">):</span> <span class="k">pass</span> </pre></div> </div> </div> <div class="class"> <h3>Ancestors (in MRO)</h3> <ul class="class_list"> <li><a href="#pyMez.Code.FrontEnds.HTMLPanel.LinkError">LinkError</a></li> <li>builtins.Exception</li> <li>builtins.BaseException</li> <li>builtins.object</li> </ul> <h3>Class variables</h3> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.LinkError.args" class="name">var <span class="ident">args</span></p> <div class="source_cont"> </div> </div> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1" class="name">class <span class="ident">Panel1</span></p> <div class="desc"><p>Panel() Panel(parent, id=ID_ANY, pos=DefaultPosition, size=DefaultSize, style=TAB_TRAVERSAL, name=PanelNameStr)</p> <p>A panel is a window on which controls are placed.</p></div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1" class="source"> <div class="codehilite"><pre><span></span><span class="k">class</span> <span class="nc">Panel1</span><span class="p">(</span><span class="n">wx</span><span class="o">.</span><span class="n">Panel</span><span class="p">):</span> <span class="n">_custom_classes</span> <span class="o">=</span> <span class="p">{</span><span class="s1">'wx.html.HtmlWindow'</span><span class="p">:</span> <span class="p">[</span><span class="s1">'HTMLWindow'</span><span class="p">]}</span> <span class="k">def</span> <span class="nf">_init_coll_boxSizer1_Items</span><span class="p">(</span><span class="bp">self</span><span class="p">,</span> <span class="n">parent</span><span class="p">):</span> <span class="c1"># generated method, don't edit</span> <span class="n">parent</span><span class="o">.</span><span class="n">Add</span><span class="p">(</span><span class="bp">self</span><span class="o">.</span><span class="n">htmlWindow1</span><span class="p">,</span> <span class="mi">1</span><span class="p">,</span> <span class="n">border</span><span class="o">=</span><span class="mi">0</span><span class="p">,</span> <span class="n">flag</span><span class="o">=</span><span class="n">wx</span><span class="o">.</span><span class="n">EXPAND</span><span class="p">)</span> <span class="k">def</span> <span class="nf">_init_sizers</span><span class="p">(</span><span class="bp">self</span><span class="p">):</span> <span class="c1"># generated method, don't edit</span> <span class="bp">self</span><span class="o">.</span><span class="n">boxSizer1</span> <span class="o">=</span> <span class="n">wx</span><span class="o">.</span><span class="n">BoxSizer</span><span class="p">(</span><span class="n">orient</span><span class="o">=</span><span class="n">wx</span><span class="o">.</span><span class="n">VERTICAL</span><span class="p">)</span> <span class="bp">self</span><span class="o">.</span><span class="n">_init_coll_boxSizer1_Items</span><span class="p">(</span><span class="bp">self</span><span class="o">.</span><span class="n">boxSizer1</span><span class="p">)</span> <span class="bp">self</span><span class="o">.</span><span class="n">SetSizer</span><span class="p">(</span><span class="bp">self</span><span class="o">.</span><span class="n">boxSizer1</span><span class="p">)</span> <span class="k">def</span> <span class="nf">_init_ctrls</span><span class="p">(</span><span class="bp">self</span><span class="p">,</span> <span class="n">prnt</span><span class="p">):</span> <span class="c1"># generated method, don't edit</span> <span class="n">wx</span><span class="o">.</span><span class="n">Panel</span><span class="o">.</span><span class="fm">__init__</span><span class="p">(</span><span class="bp">self</span><span class="p">,</span> <span class="nb">id</span><span class="o">=</span><span class="n">wxID_PANEL1</span><span class="p">,</span> <span class="n">name</span><span class="o">=</span><span class="s1">''</span><span class="p">,</span> <span class="n">parent</span><span class="o">=</span><span class="n">prnt</span><span class="p">,</span> <span class="n">pos</span><span class="o">=</span><span class="n">wx</span><span class="o">.</span><span class="n">Point</span><span class="p">(</span><span class="mi">299</span><span class="p">,</span> <span class="mi">165</span><span class="p">),</span> <span class="n">size</span><span class="o">=</span><span class="n">wx</span><span class="o">.</span><span class="n">Size</span><span class="p">(</span><span class="mi">1110</span><span class="p">,</span> <span class="mi">547</span><span class="p">),</span> <span class="n">style</span><span class="o">=</span><span class="n">wx</span><span class="o">.</span><span class="n">TAB_TRAVERSAL</span><span class="p">)</span> <span class="bp">self</span><span class="o">.</span><span class="n">SetClientSize</span><span class="p">(</span><span class="n">wx</span><span class="o">.</span><span class="n">Size</span><span class="p">(</span><span class="mi">1102</span><span class="p">,</span> <span class="mi">513</span><span class="p">))</span> <span class="bp">self</span><span class="o">.</span><span class="n">SetForegroundColour</span><span class="p">(</span><span class="n">wx</span><span class="o">.</span><span class="n">Colour</span><span class="p">(</span><span class="mi">128</span><span class="p">,</span> <span class="mi">0</span><span class="p">,</span> <span class="mi">64</span><span class="p">))</span> <span class="bp">self</span><span class="o">.</span><span class="n">htmlWindow1</span> <span class="o">=</span> <span class="n">HTMLWindow</span><span class="p">(</span><span class="nb">id</span><span class="o">=</span><span class="n">wxID_PANEL1HTMLWINDOW1</span><span class="p">,</span> <span class="n">name</span><span class="o">=</span><span class="s1">'htmlWindow1'</span><span class="p">,</span> <span class="n">parent</span><span class="o">=</span><span class="bp">self</span><span class="p">,</span> <span class="n">pos</span><span class="o">=</span><span class="n">wx</span><span class="o">.</span><span class="n">Point</span><span class="p">(</span><span class="mi">0</span><span class="p">,</span> <span class="mi">0</span><span class="p">),</span> <span class="n">size</span><span class="o">=</span><span class="n">wx</span><span class="o">.</span><span class="n">Size</span><span class="p">(</span><span class="mi">1102</span><span class="p">,</span> <span class="mi">513</span><span class="p">),</span> <span class="n">style</span><span class="o">=</span><span class="n">wx</span><span class="o">.</span><span class="n">html</span><span class="o">.</span><span class="n">HW_SCROLLBAR_AUTO</span><span class="p">)</span> <span class="bp">self</span><span class="o">.</span><span class="n">_init_sizers</span><span class="p">()</span> <span class="k">def</span> <span class="fm">__init__</span><span class="p">(</span><span class="bp">self</span><span class="p">,</span> <span class="n">parent</span><span class="p">,</span> <span class="nb">id</span><span class="p">,</span> <span class="n">pos</span><span class="p">,</span> <span class="n">size</span><span class="p">,</span> <span class="n">style</span><span class="p">,</span> <span class="n">name</span><span class="p">):</span> <span class="bp">self</span><span class="o">.</span><span class="n">_init_ctrls</span><span class="p">(</span><span class="n">parent</span><span class="p">)</span> </pre></div> </div> </div> <div class="class"> <h3>Ancestors (in MRO)</h3> <ul class="class_list"> <li><a href="#pyMez.Code.FrontEnds.HTMLPanel.Panel1">Panel1</a></li> <li>wx._core.Panel</li> <li>wx._core.Window</li> <li>wx._core.WindowBase</li> <li>wx._core.EvtHandler</li> <li>wx._core.Object</li> <li>wx._core.Trackable</li> <li>sip.wrapper</li> <li>sip.simplewrapper</li> <li>builtins.object</li> </ul> <h3>Class variables</h3> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.ChildrenRepositioningGuard" class="name">var <span class="ident">ChildrenRepositioningGuard</span></p> <div class="source_cont"> </div> </div> <h3>Static methods</h3> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.__init__"> <p>def <span class="ident">__init__</span>(</p><p>self, parent, id, pos, size, style, name)</p> </div> <div class="desc"><p>Initialize self. See help(type(self)) for accurate signature.</p></div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.__init__', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.__init__" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="fm">__init__</span><span class="p">(</span><span class="bp">self</span><span class="p">,</span> <span class="n">parent</span><span class="p">,</span> <span class="nb">id</span><span class="p">,</span> <span class="n">pos</span><span class="p">,</span> <span class="n">size</span><span class="p">,</span> <span class="n">style</span><span class="p">,</span> <span class="n">name</span><span class="p">):</span> <span class="bp">self</span><span class="o">.</span><span class="n">_init_ctrls</span><span class="p">(</span><span class="n">parent</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Bind"> <p>def <span class="ident">Bind</span>(</p><p>self, event, handler, source=None, id=-1, id2=-1)</p> </div> <div class="desc"><p>Bind an event to an event handler.</p> <p>:param event: One of the <code>EVT_*</code> event binder objects that specifies the type of event to bind.</p> <p>:param handler: A callable object to be invoked when the event is delivered to self. Pass <code>None</code> to disconnect an event handler.</p> <p>:param source: Sometimes the event originates from a different window than self, but you still want to catch it in self. (For example, a button event delivered to a frame.) By passing the source of the event, the event handling system is able to differentiate between the same event type from different controls.</p> <p>:param id: Used to spcify the event source by ID instead of instance.</p> <p>:param id2: Used when it is desirable to bind a handler to a range of IDs, such as with EVT_MENU_RANGE.</p></div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.Bind', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.Bind" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">_EvtHandler_Bind</span><span class="p">(</span><span class="bp">self</span><span class="p">,</span> <span class="n">event</span><span class="p">,</span> <span class="n">handler</span><span class="p">,</span> <span class="n">source</span><span class="o">=</span><span class="bp">None</span><span class="p">,</span> <span class="nb">id</span><span class="o">=</span><span class="n">wx</span><span class="o">.</span><span class="n">ID_ANY</span><span class="p">,</span> <span class="n">id2</span><span class="o">=</span><span class="n">wx</span><span class="o">.</span><span class="n">ID_ANY</span><span class="p">):</span> <span class="sd">"""</span> <span class="sd"> Bind an event to an event handler.</span> <span class="sd"> </span> <span class="sd"> :param event: One of the ``EVT_*`` event binder objects that</span> <span class="sd"> specifies the type of event to bind.</span> <span class="sd"> </span> <span class="sd"> :param handler: A callable object to be invoked when the</span> <span class="sd"> event is delivered to self. Pass ``None`` to</span> <span class="sd"> disconnect an event handler.</span> <span class="sd"> </span> <span class="sd"> :param source: Sometimes the event originates from a</span> <span class="sd"> different window than self, but you still</span> <span class="sd"> want to catch it in self. (For example, a</span> <span class="sd"> button event delivered to a frame.) By</span> <span class="sd"> passing the source of the event, the event</span> <span class="sd"> handling system is able to differentiate</span> <span class="sd"> between the same event type from different</span> <span class="sd"> controls.</span> <span class="sd"> </span> <span class="sd"> :param id: Used to spcify the event source by ID instead</span> <span class="sd"> of instance.</span> <span class="sd"> </span> <span class="sd"> :param id2: Used when it is desirable to bind a handler</span> <span class="sd"> to a range of IDs, such as with EVT_MENU_RANGE.</span> <span class="sd"> """</span> <span class="k">assert</span> <span class="nb">isinstance</span><span class="p">(</span><span class="n">event</span><span class="p">,</span> <span class="n">wx</span><span class="o">.</span><span class="n">PyEventBinder</span><span class="p">)</span> <span class="k">assert</span> <span class="nb">callable</span><span class="p">(</span><span class="n">handler</span><span class="p">)</span> <span class="ow">or</span> <span class="n">handler</span> <span class="ow">is</span> <span class="bp">None</span> <span class="k">assert</span> <span class="n">source</span> <span class="ow">is</span> <span class="bp">None</span> <span class="ow">or</span> <span class="nb">hasattr</span><span class="p">(</span><span class="n">source</span><span class="p">,</span> <span class="s1">'GetId'</span><span class="p">)</span> <span class="k">if</span> <span class="n">source</span> <span class="ow">is</span> <span class="ow">not</span> <span class="bp">None</span><span class="p">:</span> <span class="nb">id</span> <span class="o">=</span> <span class="n">source</span><span class="o">.</span><span class="n">GetId</span><span class="p">()</span> <span class="n">event</span><span class="o">.</span><span class="n">Bind</span><span class="p">(</span><span class="bp">self</span><span class="p">,</span> <span class="nb">id</span><span class="p">,</span> <span class="n">id2</span><span class="p">,</span> <span class="n">handler</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.ConvertDialogPointToPixels"> <p>def <span class="ident">ConvertDialogPointToPixels</span>(</p><p>*args, **kw)</p> </div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.ConvertDialogPointToPixels', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.ConvertDialogPointToPixels" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">deprecated_func</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">):</span> <span class="n">warnings</span><span class="o">.</span><span class="n">warn</span><span class="p">(</span><span class="s2">"Call to deprecated item</span><span class="si">%s</span><span class="s2">. </span><span class="si">%s</span><span class="s2">"</span> <span class="o">%</span> <span class="p">(</span><span class="n">name</span><span class="p">,</span> <span class="n">msg</span><span class="p">),</span> <span class="n">wxPyDeprecationWarning</span><span class="p">,</span> <span class="n">stacklevel</span><span class="o">=</span><span class="mi">2</span><span class="p">)</span> <span class="k">if</span> <span class="ow">not</span> <span class="n">kw</span><span class="p">:</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">)</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.ConvertDialogSizeToPixels"> <p>def <span class="ident">ConvertDialogSizeToPixels</span>(</p><p>*args, **kw)</p> </div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.ConvertDialogSizeToPixels', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.ConvertDialogSizeToPixels" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">deprecated_func</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">):</span> <span class="n">warnings</span><span class="o">.</span><span class="n">warn</span><span class="p">(</span><span class="s2">"Call to deprecated item</span><span class="si">%s</span><span class="s2">. </span><span class="si">%s</span><span class="s2">"</span> <span class="o">%</span> <span class="p">(</span><span class="n">name</span><span class="p">,</span> <span class="n">msg</span><span class="p">),</span> <span class="n">wxPyDeprecationWarning</span><span class="p">,</span> <span class="n">stacklevel</span><span class="o">=</span><span class="mi">2</span><span class="p">)</span> <span class="k">if</span> <span class="ow">not</span> <span class="n">kw</span><span class="p">:</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">)</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.DLG_UNIT"> <p>def <span class="ident">DLG_UNIT</span>(</p><p>self, dlg_unit)</p> </div> <div class="desc"><p>A convenience wrapper for :meth:<code>ConvertDialogToPixels</code>.</p></div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.DLG_UNIT', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.DLG_UNIT" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">_Window_DLG_UNIT</span><span class="p">(</span><span class="bp">self</span><span class="p">,</span> <span class="n">dlg_unit</span><span class="p">):</span> <span class="sd">"""</span> <span class="sd"> A convenience wrapper for :meth:`ConvertDialogToPixels`.</span> <span class="sd"> """</span> <span class="n">is_wxType</span> <span class="o">=</span> <span class="nb">isinstance</span><span class="p">(</span><span class="n">dlg_unit</span><span class="p">,</span> <span class="p">(</span><span class="n">wx</span><span class="o">.</span><span class="n">Size</span><span class="p">,</span> <span class="n">wx</span><span class="o">.</span><span class="n">Point</span><span class="p">))</span> <span class="n">pix</span> <span class="o">=</span> <span class="bp">self</span><span class="o">.</span><span class="n">ConvertDialogToPixels</span><span class="p">(</span><span class="n">dlg_unit</span><span class="p">)</span> <span class="k">if</span> <span class="ow">not</span> <span class="n">is_wxType</span><span class="p">:</span> <span class="n">pix</span> <span class="o">=</span> <span class="nb">tuple</span><span class="p">(</span><span class="n">pix</span><span class="p">)</span> <span class="k">return</span> <span class="n">pix</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.DestroyLater"> <p>def <span class="ident">DestroyLater</span>(</p><p>self)</p> </div> <div class="desc"><p>Schedules the window to be destroyed in the near future.</p> <p>This should be used whenever Destroy could happen too soon, such as when there may still be events for this window or its children waiting in the event queue.</p></div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.DestroyLater', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.DestroyLater" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">_Window_DestroyLater</span><span class="p">(</span><span class="bp">self</span><span class="p">):</span> <span class="sd">"""</span> <span class="sd"> Schedules the window to be destroyed in the near future.</span> <span class="sd"> </span> <span class="sd"> This should be used whenever Destroy could happen too soon, such</span> <span class="sd"> as when there may still be events for this window or its children</span> <span class="sd"> waiting in the event queue.</span> <span class="sd"> """</span> <span class="bp">self</span><span class="o">.</span><span class="n">Hide</span><span class="p">()</span> <span class="n">wx</span><span class="o">.</span><span class="n">GetApp</span><span class="p">()</span><span class="o">.</span><span class="n">ScheduleForDestruction</span><span class="p">(</span><span class="bp">self</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.GetPositionTuple"> <p>def <span class="ident">GetPositionTuple</span>(</p><p>*args, **kw)</p> </div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.GetPositionTuple', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.GetPositionTuple" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">deprecated_func</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">):</span> <span class="n">warnings</span><span class="o">.</span><span class="n">warn</span><span class="p">(</span><span class="s2">"Call to deprecated item</span><span class="si">%s</span><span class="s2">. </span><span class="si">%s</span><span class="s2">"</span> <span class="o">%</span> <span class="p">(</span><span class="n">name</span><span class="p">,</span> <span class="n">msg</span><span class="p">),</span> <span class="n">wxPyDeprecationWarning</span><span class="p">,</span> <span class="n">stacklevel</span><span class="o">=</span><span class="mi">2</span><span class="p">)</span> <span class="k">if</span> <span class="ow">not</span> <span class="n">kw</span><span class="p">:</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">)</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.GetSizeTuple"> <p>def <span class="ident">GetSizeTuple</span>(</p><p>*args, **kw)</p> </div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.GetSizeTuple', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.GetSizeTuple" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">deprecated_func</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">):</span> <span class="n">warnings</span><span class="o">.</span><span class="n">warn</span><span class="p">(</span><span class="s2">"Call to deprecated item</span><span class="si">%s</span><span class="s2">. </span><span class="si">%s</span><span class="s2">"</span> <span class="o">%</span> <span class="p">(</span><span class="n">name</span><span class="p">,</span> <span class="n">msg</span><span class="p">),</span> <span class="n">wxPyDeprecationWarning</span><span class="p">,</span> <span class="n">stacklevel</span><span class="o">=</span><span class="mi">2</span><span class="p">)</span> <span class="k">if</span> <span class="ow">not</span> <span class="n">kw</span><span class="p">:</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">)</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.GetVirtualSizeTuple"> <p>def <span class="ident">GetVirtualSizeTuple</span>(</p><p>*args, **kw)</p> </div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.GetVirtualSizeTuple', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.GetVirtualSizeTuple" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">deprecated_func</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">):</span> <span class="n">warnings</span><span class="o">.</span><span class="n">warn</span><span class="p">(</span><span class="s2">"Call to deprecated item</span><span class="si">%s</span><span class="s2">. </span><span class="si">%s</span><span class="s2">"</span> <span class="o">%</span> <span class="p">(</span><span class="n">name</span><span class="p">,</span> <span class="n">msg</span><span class="p">),</span> <span class="n">wxPyDeprecationWarning</span><span class="p">,</span> <span class="n">stacklevel</span><span class="o">=</span><span class="mi">2</span><span class="p">)</span> <span class="k">if</span> <span class="ow">not</span> <span class="n">kw</span><span class="p">:</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">)</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.MoveXY"> <p>def <span class="ident">MoveXY</span>(</p><p>*args, **kw)</p> </div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.MoveXY', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.MoveXY" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">deprecated_func</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">):</span> <span class="n">warnings</span><span class="o">.</span><span class="n">warn</span><span class="p">(</span><span class="s2">"Call to deprecated item</span><span class="si">%s</span><span class="s2">. </span><span class="si">%s</span><span class="s2">"</span> <span class="o">%</span> <span class="p">(</span><span class="n">name</span><span class="p">,</span> <span class="n">msg</span><span class="p">),</span> <span class="n">wxPyDeprecationWarning</span><span class="p">,</span> <span class="n">stacklevel</span><span class="o">=</span><span class="mi">2</span><span class="p">)</span> <span class="k">if</span> <span class="ow">not</span> <span class="n">kw</span><span class="p">:</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">)</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.PostCreate"> <p>def <span class="ident">PostCreate</span>(</p><p>*args, **kw)</p> </div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.PostCreate', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.PostCreate" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">deprecated_func</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">):</span> <span class="n">warnings</span><span class="o">.</span><span class="n">warn</span><span class="p">(</span><span class="s2">"Call to deprecated item</span><span class="si">%s</span><span class="s2">. </span><span class="si">%s</span><span class="s2">"</span> <span class="o">%</span> <span class="p">(</span><span class="n">name</span><span class="p">,</span> <span class="n">msg</span><span class="p">),</span> <span class="n">wxPyDeprecationWarning</span><span class="p">,</span> <span class="n">stacklevel</span><span class="o">=</span><span class="mi">2</span><span class="p">)</span> <span class="k">if</span> <span class="ow">not</span> <span class="n">kw</span><span class="p">:</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">)</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetClientRect"> <p>def <span class="ident">SetClientRect</span>(</p><p>self, rect)</p> </div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetClientRect', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetClientRect" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">_Window_SetClientRect</span><span class="p">(</span><span class="bp">self</span><span class="p">,</span> <span class="n">rect</span><span class="p">):</span> <span class="k">return</span> <span class="bp">self</span><span class="o">.</span><span class="n">SetClientSize</span><span class="p">(</span><span class="n">rect</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetDimensions"> <p>def <span class="ident">SetDimensions</span>(</p><p>*args, **kw)</p> </div> <div class="desc"><p>SetDimensions(x, y, width, height, sizeFlags=SIZE_AUTO)</p></div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetDimensions', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetDimensions" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">deprecated_func</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">):</span> <span class="n">warnings</span><span class="o">.</span><span class="n">warn</span><span class="p">(</span><span class="s2">"Call to deprecated item</span><span class="si">%s</span><span class="s2">. </span><span class="si">%s</span><span class="s2">"</span> <span class="o">%</span> <span class="p">(</span><span class="n">name</span><span class="p">,</span> <span class="n">msg</span><span class="p">),</span> <span class="n">wxPyDeprecationWarning</span><span class="p">,</span> <span class="n">stacklevel</span><span class="o">=</span><span class="mi">2</span><span class="p">)</span> <span class="k">if</span> <span class="ow">not</span> <span class="n">kw</span><span class="p">:</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">)</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetRect"> <p>def <span class="ident">SetRect</span>(</p><p>self, rect)</p> </div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetRect', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetRect" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">_Window_SetRect</span><span class="p">(</span><span class="bp">self</span><span class="p">,</span> <span class="n">rect</span><span class="p">):</span> <span class="k">return</span> <span class="bp">self</span><span class="o">.</span><span class="n">SetSize</span><span class="p">(</span><span class="n">rect</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetSizeHintsSz"> <p>def <span class="ident">SetSizeHintsSz</span>(</p><p>*args, **kw)</p> </div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetSizeHintsSz', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetSizeHintsSz" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">deprecated_func</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">):</span> <span class="n">warnings</span><span class="o">.</span><span class="n">warn</span><span class="p">(</span><span class="s2">"Call to deprecated item</span><span class="si">%s</span><span class="s2">. </span><span class="si">%s</span><span class="s2">"</span> <span class="o">%</span> <span class="p">(</span><span class="n">name</span><span class="p">,</span> <span class="n">msg</span><span class="p">),</span> <span class="n">wxPyDeprecationWarning</span><span class="p">,</span> <span class="n">stacklevel</span><span class="o">=</span><span class="mi">2</span><span class="p">)</span> <span class="k">if</span> <span class="ow">not</span> <span class="n">kw</span><span class="p">:</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">)</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetSizeWH"> <p>def <span class="ident">SetSizeWH</span>(</p><p>*args, **kw)</p> </div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetSizeWH', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetSizeWH" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">deprecated_func</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">):</span> <span class="n">warnings</span><span class="o">.</span><span class="n">warn</span><span class="p">(</span><span class="s2">"Call to deprecated item</span><span class="si">%s</span><span class="s2">. </span><span class="si">%s</span><span class="s2">"</span> <span class="o">%</span> <span class="p">(</span><span class="n">name</span><span class="p">,</span> <span class="n">msg</span><span class="p">),</span> <span class="n">wxPyDeprecationWarning</span><span class="p">,</span> <span class="n">stacklevel</span><span class="o">=</span><span class="mi">2</span><span class="p">)</span> <span class="k">if</span> <span class="ow">not</span> <span class="n">kw</span><span class="p">:</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">)</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetToolTipString"> <p>def <span class="ident">SetToolTipString</span>(</p><p>*args, **kw)</p> </div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetToolTipString', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetToolTipString" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">deprecated_func</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">):</span> <span class="n">warnings</span><span class="o">.</span><span class="n">warn</span><span class="p">(</span><span class="s2">"Call to deprecated item</span><span class="si">%s</span><span class="s2">. </span><span class="si">%s</span><span class="s2">"</span> <span class="o">%</span> <span class="p">(</span><span class="n">name</span><span class="p">,</span> <span class="n">msg</span><span class="p">),</span> <span class="n">wxPyDeprecationWarning</span><span class="p">,</span> <span class="n">stacklevel</span><span class="o">=</span><span class="mi">2</span><span class="p">)</span> <span class="k">if</span> <span class="ow">not</span> <span class="n">kw</span><span class="p">:</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">)</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetVirtualSizeWH"> <p>def <span class="ident">SetVirtualSizeWH</span>(</p><p>*args, **kw)</p> </div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetVirtualSizeWH', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.SetVirtualSizeWH" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">deprecated_func</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">):</span> <span class="n">warnings</span><span class="o">.</span><span class="n">warn</span><span class="p">(</span><span class="s2">"Call to deprecated item</span><span class="si">%s</span><span class="s2">. </span><span class="si">%s</span><span class="s2">"</span> <span class="o">%</span> <span class="p">(</span><span class="n">name</span><span class="p">,</span> <span class="n">msg</span><span class="p">),</span> <span class="n">wxPyDeprecationWarning</span><span class="p">,</span> <span class="n">stacklevel</span><span class="o">=</span><span class="mi">2</span><span class="p">)</span> <span class="k">if</span> <span class="ow">not</span> <span class="n">kw</span><span class="p">:</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">)</span> <span class="k">return</span> <span class="n">item</span><span class="p">(</span><span class="o">*</span><span class="n">args</span><span class="p">,</span> <span class="o">**</span><span class="n">kw</span><span class="p">)</span> </pre></div> </div> </div> </div> <div class="item"> <div class="name def" id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Unbind"> <p>def <span class="ident">Unbind</span>(</p><p>self, event, source=None, id=-1, id2=-1, handler=None)</p> </div> <div class="desc"><p>Disconnects the event handler binding for event from <code>self</code>. Returns <code>True</code> if successful.</p></div> <div class="source_cont"> <p class="source_link"><a href="javascript:void(0);" onclick="toggle('source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.Unbind', this);">Show source ≡</a></p> <div id="source-pyMez.Code.FrontEnds.HTMLPanel.Panel1.Unbind" class="source"> <div class="codehilite"><pre><span></span><span class="k">def</span> <span class="nf">_EvtHandler_Unbind</span><span class="p">(</span><span class="bp">self</span><span class="p">,</span> <span class="n">event</span><span class="p">,</span> <span class="n">source</span><span class="o">=</span><span class="bp">None</span><span class="p">,</span> <span class="nb">id</span><span class="o">=</span><span class="n">wx</span><span class="o">.</span><span class="n">ID_ANY</span><span class="p">,</span> <span class="n">id2</span><span class="o">=</span><span class="n">wx</span><span class="o">.</span><span class="n">ID_ANY</span><span class="p">,</span> <span class="n">handler</span><span class="o">=</span><span class="bp">None</span><span class="p">):</span> <span class="sd">"""</span> <span class="sd"> Disconnects the event handler binding for event from `self`.</span> <span class="sd"> Returns ``True`` if successful.</span> <span class="sd"> """</span> <span class="k">if</span> <span class="n">source</span> <span class="ow">is</span> <span class="ow">not</span> <span class="bp">None</span><span class="p">:</span> <span class="nb">id</span> <span class="o">=</span> <span class="n">source</span><span class="o">.</span><span class="n">GetId</span><span class="p">()</span> <span class="k">return</span> <span class="n">event</span><span class="o">.</span><span class="n">Unbind</span><span class="p">(</span><span class="bp">self</span><span class="p">,</span> <span class="nb">id</span><span class="p">,</span> <span class="n">id2</span><span class="p">,</span> <span class="n">handler</span><span class="p">)</span> </pre></div> </div> </div> </div> <h3>Instance variables</h3> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.AcceleratorTable" class="name">var <span class="ident">AcceleratorTable</span></p> <div class="desc"><p>GetAcceleratorTable() -> AcceleratorTable</p> <p>Gets the accelerator table for this window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.AutoLayout" class="name">var <span class="ident">AutoLayout</span></p> <div class="desc"><p>GetAutoLayout() -> bool</p> <p>Returns the sizer of which this window is a member, if any, otherwise NULL.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.BackgroundColour" class="name">var <span class="ident">BackgroundColour</span></p> <div class="desc"><p>GetBackgroundColour() -> Colour</p> <p>Returns the background colour of the window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.BackgroundStyle" class="name">var <span class="ident">BackgroundStyle</span></p> <div class="desc"><p>GetBackgroundStyle() -> BackgroundStyle</p> <p>Returns the background style of the window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.BestSize" class="name">var <span class="ident">BestSize</span></p> <div class="desc"><p>GetBestSize() -> Size</p> <p>This functions returns the best acceptable minimal size for the window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.BestVirtualSize" class="name">var <span class="ident">BestVirtualSize</span></p> <div class="desc"><p>GetBestVirtualSize() -> Size</p> <p>Return the largest of ClientSize and BestSize (as determined by a sizer, interior children, or other means)</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Border" class="name">var <span class="ident">Border</span></p> <div class="desc"><p>GetBorder(flags) -> Border GetBorder() -> Border</p> <p>Get the window border style from the given flags: this is different from simply doing flags & wxBORDER_MASK because it uses GetDefaultBorder() to translate wxBORDER_DEFAULT to something reasonable.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Caret" class="name">var <span class="ident">Caret</span></p> <div class="desc"><p>GetCaret() -> Caret</p> <p>Returns the caret() associated with the window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.CharHeight" class="name">var <span class="ident">CharHeight</span></p> <div class="desc"><p>GetCharHeight() -> int</p> <p>Returns the character height for this window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.CharWidth" class="name">var <span class="ident">CharWidth</span></p> <div class="desc"><p>GetCharWidth() -> int</p> <p>Returns the average character width for this window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Children" class="name">var <span class="ident">Children</span></p> <div class="desc"><p>GetChildren() -> WindowList</p> <p>Returns a reference to the list of the window's children.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.ClassInfo" class="name">var <span class="ident">ClassInfo</span></p> <div class="desc"><p>GetClassInfo() -> ClassInfo</p> <p>This virtual function is redefined for every class that requires run- time type information, when using the wxDECLARE_CLASS macro (or similar).</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.ClassName" class="name">var <span class="ident">ClassName</span></p> <div class="desc"><p>GetClassName() -> Char</p> <p>Returns the class name of the C++ class using wxRTTI.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.ClientAreaOrigin" class="name">var <span class="ident">ClientAreaOrigin</span></p> <div class="desc"><p>GetClientAreaOrigin() -> Point</p> <p>Get the origin of the client area of the window relative to the window top left corner (the client area may be shifted because of the borders, scrollbars, other decorations...)</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.ClientRect" class="name">var <span class="ident">ClientRect</span></p> <div class="desc"><p>GetClientRect() -> Rect</p> <p>Get the client rectangle in window (i.e. client) coordinates.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.ClientSize" class="name">var <span class="ident">ClientSize</span></p> <div class="desc"><p>GetClientSize() -> Size</p> <p>Returns the size of the window 'client area' in pixels.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Constraints" class="name">var <span class="ident">Constraints</span></p> <div class="desc"><p>GetConstraints() -> LayoutConstraints</p> <p>Returns a pointer to the window's layout constraints, or NULL if there are none.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.ContainingSizer" class="name">var <span class="ident">ContainingSizer</span></p> <div class="desc"><p>GetContainingSizer() -> Sizer</p> <p>Returns the sizer of which this window is a member, if any, otherwise NULL.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Cursor" class="name">var <span class="ident">Cursor</span></p> <div class="desc"><p>GetCursor() -> Cursor</p> <p>Return the cursor associated with this window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.DefaultAttributes" class="name">var <span class="ident">DefaultAttributes</span></p> <div class="desc"><p>GetDefaultAttributes() -> VisualAttributes</p> <p>Currently this is the same as calling wxWindow::GetClassDefaultAttributes(wxWindow::GetWindowVariant()).</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.DropTarget" class="name">var <span class="ident">DropTarget</span></p> <div class="desc"><p>GetDropTarget() -> DropTarget</p> <p>Returns the associated drop target, which may be NULL.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.EffectiveMinSize" class="name">var <span class="ident">EffectiveMinSize</span></p> <div class="desc"><p>GetEffectiveMinSize() -> Size</p> <p>Merges the window's best size into the min size and returns the result.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Enabled" class="name">var <span class="ident">Enabled</span></p> <div class="desc"><p>IsEnabled() -> bool</p> <p>Returns true if the window is enabled, i.e. if it accepts user input, false otherwise.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.EventHandler" class="name">var <span class="ident">EventHandler</span></p> <div class="desc"><p>GetEventHandler() -> EvtHandler</p> <p>Returns the event handler for this window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.EvtHandlerEnabled" class="name">var <span class="ident">EvtHandlerEnabled</span></p> <div class="desc"><p>GetEvtHandlerEnabled() -> bool</p> <p>Returns true if the event handler is enabled, false otherwise.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.ExtraStyle" class="name">var <span class="ident">ExtraStyle</span></p> <div class="desc"><p>GetExtraStyle() -> long</p> <p>Returns the extra style bits for the window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Font" class="name">var <span class="ident">Font</span></p> <div class="desc"><p>GetFont() -> Font</p> <p>Returns the font for this window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.ForegroundColour" class="name">var <span class="ident">ForegroundColour</span></p> <div class="desc"><p>GetForegroundColour() -> Colour</p> <p>Returns the foreground colour of the window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.GrandParent" class="name">var <span class="ident">GrandParent</span></p> <div class="desc"><p>GetGrandParent() -> Window</p> <p>Returns the grandparent of a window, or NULL if there isn't one.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Handle" class="name">var <span class="ident">Handle</span></p> <div class="desc"><p>GetHandle() -> UIntPtr</p> <p>Returns the platform-specific handle of the physical window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.HelpText" class="name">var <span class="ident">HelpText</span></p> <div class="desc"><p>GetHelpText() -> String</p> <p>Gets the help text to be used as context-sensitive help for this window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Id" class="name">var <span class="ident">Id</span></p> <div class="desc"><p>GetId() -> WindowID</p> <p>Returns the identifier of the window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Label" class="name">var <span class="ident">Label</span></p> <div class="desc"><p>GetLabel() -> String</p> <p>Generic way of getting a label from any window, for identification purposes.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.LayoutDirection" class="name">var <span class="ident">LayoutDirection</span></p> <div class="desc"><p>GetLayoutDirection() -> LayoutDirection</p> <p>Returns the layout direction for this window, Note that wxLayout_Default is returned if layout direction is not supported.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.MaxClientSize" class="name">var <span class="ident">MaxClientSize</span></p> <div class="desc"><p>GetMaxClientSize() -> Size</p> <p>Returns the maximum size of window's client area.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.MaxHeight" class="name">var <span class="ident">MaxHeight</span></p> <div class="desc"><p>GetMaxHeight() -> int</p> <p>Returns the vertical component of window maximal size.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.MaxSize" class="name">var <span class="ident">MaxSize</span></p> <div class="desc"><p>GetMaxSize() -> Size</p> <p>Returns the maximum size of the window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.MaxWidth" class="name">var <span class="ident">MaxWidth</span></p> <div class="desc"><p>GetMaxWidth() -> int</p> <p>Returns the horizontal component of window maximal size.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.MinClientSize" class="name">var <span class="ident">MinClientSize</span></p> <div class="desc"><p>GetMinClientSize() -> Size</p> <p>Returns the minimum size of window's client area, an indication to the sizer layout mechanism that this is the minimum required size of its client area.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.MinHeight" class="name">var <span class="ident">MinHeight</span></p> <div class="desc"><p>GetMinHeight() -> int</p> <p>Returns the vertical component of window minimal size.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.MinSize" class="name">var <span class="ident">MinSize</span></p> <div class="desc"><p>GetMinSize() -> Size</p> <p>Returns the minimum size of the window, an indication to the sizer layout mechanism that this is the minimum required size.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.MinWidth" class="name">var <span class="ident">MinWidth</span></p> <div class="desc"><p>GetMinWidth() -> int</p> <p>Returns the horizontal component of window minimal size.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Name" class="name">var <span class="ident">Name</span></p> <div class="desc"><p>GetName() -> String</p> <p>Returns the window's name.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.NextHandler" class="name">var <span class="ident">NextHandler</span></p> <div class="desc"><p>GetNextHandler() -> EvtHandler</p> <p>Returns the pointer to the next handler in the chain.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Parent" class="name">var <span class="ident">Parent</span></p> <div class="desc"><p>GetParent() -> Window</p> <p>Returns the parent of the window, or NULL if there is no parent.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Position" class="name">var <span class="ident">Position</span></p> <div class="desc"><p>GetPosition() -> Point</p> <p>This gets the position of the window in pixels, relative to the parent window for the child windows or relative to the display origin for the top level windows.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.PreviousHandler" class="name">var <span class="ident">PreviousHandler</span></p> <div class="desc"><p>GetPreviousHandler() -> EvtHandler</p> <p>Returns the pointer to the previous handler in the chain.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Rect" class="name">var <span class="ident">Rect</span></p> <div class="desc"><p>GetRect() -> Rect</p> <p>Returns the position and size of the window as a wxRect object.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.RefData" class="name">var <span class="ident">RefData</span></p> <div class="desc"><p>GetRefData() -> ObjectRefData</p> <p>Returns the wxObject::m_refData pointer, i.e. the data referenced by this object.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.ScreenPosition" class="name">var <span class="ident">ScreenPosition</span></p> <div class="desc"><p>GetScreenPosition() -> Point</p> <p>Returns the window position in screen coordinates, whether the window is a child window or a top level one.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.ScreenRect" class="name">var <span class="ident">ScreenRect</span></p> <div class="desc"><p>GetScreenRect() -> Rect</p> <p>Returns the position and size of the window on the screen as a wxRect object.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Shown" class="name">var <span class="ident">Shown</span></p> <div class="desc"><p>IsShown() -> bool</p> <p>Returns true if the window is shown, false if it has been hidden.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Size" class="name">var <span class="ident">Size</span></p> <div class="desc"><p>GetSize() -> Size</p> <p>Returns the size of the entire window in pixels, including title bar, border, scrollbars, etc.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Sizer" class="name">var <span class="ident">Sizer</span></p> <div class="desc"><p>GetSizer() -> Sizer</p> <p>Returns the sizer associated with the window by a previous call to SetSizer(), or NULL.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.ThemeEnabled" class="name">var <span class="ident">ThemeEnabled</span></p> <div class="desc"><p>GetThemeEnabled() -> bool</p> <p>Clears the window by filling it with the current background colour.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.ToolTip" class="name">var <span class="ident">ToolTip</span></p> <div class="desc"><p>GetToolTip() -> ToolTip</p> <p>Get the associated tooltip or NULL if none.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.TopLevel" class="name">var <span class="ident">TopLevel</span></p> <div class="desc"><p>IsTopLevel() -> bool</p> <p>Returns true if the given window is a top-level one.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.TopLevelParent" class="name">var <span class="ident">TopLevelParent</span></p> <div class="desc"><p>GetTopLevelParent() -> Window</p> <p>Returns the first ancestor of this window which is a top-level window.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.UpdateClientRect" class="name">var <span class="ident">UpdateClientRect</span></p> <div class="desc"><p>GetUpdateClientRect() -> Rect</p> <p>Get the update rectangle bounding box in client coords.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.UpdateRegion" class="name">var <span class="ident">UpdateRegion</span></p> <div class="desc"><p>GetUpdateRegion() -> Region</p> <p>Returns the region specifying which parts of the window have been damaged.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.Validator" class="name">var <span class="ident">Validator</span></p> <div class="desc"><p>GetValidator() -> Validator</p> <p>Validator functions.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.VirtualSize" class="name">var <span class="ident">VirtualSize</span></p> <div class="desc"><p>GetVirtualSize() -> Size</p> <p>This gets the virtual size of the window in pixels.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.WindowStyle" class="name">var <span class="ident">WindowStyle</span></p> <div class="desc"><p>GetWindowStyle() -> long</p> <p>See GetWindowStyleFlag() for more info.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.WindowStyleFlag" class="name">var <span class="ident">WindowStyleFlag</span></p> <div class="desc"><p>GetWindowStyleFlag() -> long</p> <p>Gets the window style that was passed to the constructor or Create() method.</p></div> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.Panel1.WindowVariant" class="name">var <span class="ident">WindowVariant</span></p> <div class="desc"><p>GetWindowVariant() -> WindowVariant</p> <p>Returns the value previously passed to SetWindowVariant().</p></div> <div class="source_cont"> </div> </div> </div> </div> <h2 class="section-title" id="header-variables">Module variables</h2> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.TEST_HTML" class="name">var <span class="ident">TEST_HTML</span></p> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.wxID_PANEL1" class="name">var <span class="ident">wxID_PANEL1</span></p> <div class="source_cont"> </div> </div> <div class="item"> <p id="pyMez.Code.FrontEnds.HTMLPanel.wxID_PANEL1HTMLWINDOW1" class="name">var <span class="ident">wxID_PANEL1HTMLWINDOW1</span></p> <div class="source_cont"> </div> </div> </section> </article> <div class="clear"> </div> <footer id="footer"> <p> Documentation generated by <a href="https://github.com/BurntSushi/pdoc">pdoc 0.3.2</a> </p> <p>pdoc is in the public domain with the <a href="http://unlicense.org">UNLICENSE</a></p> <p>Design by <a href="http://nadh.in">Kailash Nadh</a></p> </footer> </div> </body> </html>